@@ -3,13 +3,6 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'AR': 'ar',
  'ARFLAGS': 'rc',
- 'ASDLGEN': './Parser/asdl_c.py',
- 'ASDLGEN_FILES': './Parser/asdl.py ./Parser/asdl_c.py',
- 'AST_ASDL': './Parser/Python.asdl',
- 'AST_C': 'Python/Python-ast.c',
- 'AST_C_DIR': 'Python',
- 'AST_H': 'Include/Python-ast.h',
- 'AST_H_DIR': 'Include',
  'ATHEOS_THREADS': 0,
  'BASECFLAGS': '-fno-strict-aliasing',
  'BASEMODLIBS': '',
@@ -17,20 +10,20 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'BINDIR': '/usr/bin',
  'BINLIBDEST': '/usr/lib/python2.7',
  'BLDLIBRARY': '-L. -lpython2.7',
- 'BLDSHARED': 'gcc -pthread -shared -Wl,-O1,--sort-common,--as-needed,-z,relro',
+ 'BLDSHARED': 'gcc -pthread -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-aliasing -march=armv8-a -O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4 -DNDEBUG -march=armv8-a -O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4',
+ 'CFLAGS': '-fno-strict-aliasing -march=armv8-a -O2 -pipe -fstack-protector-strong -fno-plt -DNDEBUG -march=armv8-a -O2 -pipe -fstack-protector-strong -fno-plt',
  'CFLAGSFORSHARED': '-fPIC',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
- 'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-threads' '--enable-optimizations' '--with-lto' '--enable-ipv6' '--enable-unicode=ucs4' '--with-system-expat' '--with-system-ffi' '--with-dbmliborder=gdbm:ndbm' '--without-ensurepip' 'CFLAGS=-march=armv8-a -O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4' 'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro' 'CPPFLAGS=-D_FORTIFY_SOURCE=2'",
+ 'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-threads' '--enable-optimizations' '--without-lto' '--enable-ipv6' '--enable-unicode=ucs4' '--with-system-expat' '--with-system-ffi' '--with-dbmliborder=gdbm:ndbm' '--without-ensurepip' 'CFLAGS=-march=armv8-a -O2 -pipe -fstack-protector-strong -fno-plt' 'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now' 'CPPFLAGS=-D_FORTIFY_SOURCE=2'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python2.7',
  'COREPYTHONPATH': ':plat-linux2:lib-tk:lib-old',
- 'COVERAGE_INFO': '/build/python2/src/Python-2.7.13/coverage.info',
- 'COVERAGE_REPORT': '/build/python2/src/Python-2.7.13/lcov-report',
+ 'COVERAGE_INFO': '/build/python2/src/Python-2.7.14/coverage.info',
+ 'COVERAGE_REPORT': '/build/python2/src/Python-2.7.14/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
  'CPPFLAGS': '-I. -IInclude -I./Include -D_FORTIFY_SOURCE=2',
  'CXX': 'g++ -pthread',
@@ -61,11 +54,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
  'GETTIMEOFDAY_NO_TZ': 0,
+ 'GITBRANCH': '',
+ 'GITTAG': '',
+ 'GITVERSION': '',
  'GLHACK': '-Dclear=__GLclear',
  'GNULD': 'yes',
- 'GRAMMAR_C': 'Python/graminit.c',
- 'GRAMMAR_H': 'Include/graminit.h',
- 'GRAMMAR_INPUT': './Grammar/Grammar',
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
  'HAVE_ALARM': 1,
@@ -307,6 +300,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_SYS_NDIR_H': 0,
  'HAVE_SYS_PARAM_H': 1,
  'HAVE_SYS_POLL_H': 1,
+ 'HAVE_SYS_RANDOM_H': 1,
  'HAVE_SYS_RESOURCE_H': 1,
  'HAVE_SYS_SELECT_H': 1,
  'HAVE_SYS_SOCKET_H': 1,
@@ -353,9 +347,6 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HGBRANCH': '',
- 'HGTAG': '',
- 'HGVERSION': '',
  'HOST_GNU_TYPE': 'aarch64-unknown-linux-gnu',
  'HURD_C_THREADS': 0,
  'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python2.7 /usr/include/python2.7',
@@ -368,11 +359,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'INSTALL_SHARED': '/usr/bin/install -c -m 555',
  'INSTSONAME': 'libpython2.7.so.1.0',
  'LDCXXSHARED': 'g++ -pthread -shared',
- 'LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro',
+ 'LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'LDLAST': '',
  'LDLIBRARY': 'libpython2.7.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -pthread -shared -Wl,-O1,--sort-common,--as-needed,-z,relro',
+ 'LDSHARED': 'gcc -pthread -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'LIBC': '',
  'LIBDEST': '/usr/lib/python2.7',
  'LIBDIR': '/usr/lib',
@@ -415,10 +406,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'MVWDELCH_IS_EXPRESSION': 1,
  'OBJECT_OBJS': '\\',
  'OLDPATH': ':lib-old',
- 'OPCODETARGETGEN': '\\',
- 'OPCODETARGETGEN_FILES': '\\',
- 'OPCODETARGETS_H': '\\',
- 'OPT': '-DNDEBUG -march=armv8-a -O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4',
+ 'OPT': '-DNDEBUG -march=armv8-a -O2 -pipe -fstack-protector-strong -fno-plt',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -452,9 +440,10 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': ':plat-linux2:lib-tk:lib-old',
  'PYTHON_FOR_BUILD': './python -E',
+ 'PYTHON_FOR_REGEN': 'python3',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-fno-strict-aliasing -march=armv8-a -O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4 -DNDEBUG -march=armv8-a -O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4 -I. -IInclude -I./Include -D_FORTIFY_SOURCE=2 -fPIC -DPy_BUILD_CORE',
+ 'PY_CFLAGS': '-fno-strict-aliasing -march=armv8-a -O2 -pipe -fstack-protector-strong -fno-plt -DNDEBUG -march=armv8-a -O2 -pipe -fstack-protector-strong -fno-plt -I. -IInclude -I./Include -D_FORTIFY_SOURCE=2 -fPIC -DPy_BUILD_CORE',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_UNICODE_TYPE': 'wchar_t',
@@ -466,7 +455,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'RANLIB': 'ranlib',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python2/src/Python-2.7.13',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python2/src/Python-2.7.14',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
@@ -494,14 +483,13 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SO': '.so',
- 'SRCDIRS': 'Parser Grammar Objects Python Modules Mac',
+ 'SRCDIRS': 'Parser Objects Python Modules',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRINGLIB_HEADERS': '\\',
  'SUBDIRS': '',
  'SUBDIRSTOO': 'Include Lib Misc Demo',
- 'SVNVERSION': 'echo Unversioned directory',
  'SYSLIBS': '-lm',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TANH_PRESERVES_ZERO_SIGN': 1,
@@ -510,7 +498,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'TESTOPTS': '-l',
  'TESTPATH': '',
  'TESTPROG': './Lib/test/regrtest.py',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python2/src/Python-2.7.13 ./python -Wd -3 -E -tt',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python2/src/Python-2.7.14 ./python -Wd -3 -E -tt',
  'TESTPYTHONOPTS': '',
  'THREADOBJ': 'Python/thread.o',
  'TIME_WITH_SYS_TIME': 1,
@@ -535,8 +523,8 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python2/src/Python-2.7.13',
- 'abs_srcdir': '/build/python2/src/Python-2.7.13',
+ 'abs_builddir': '/build/python2/src/Python-2.7.14',
+ 'abs_srcdir': '/build/python2/src/Python-2.7.14',
  'build': 'aarch64-unknown-linux-gnu',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
